@@ -1,4 +1,3 @@
-
 ##
 #    
 #    Copyright (C) 2007  Mola Pahnadayan
@@ -21,4 +20,7 @@
 holiday = { 1386:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[1,17],
                   [2,14],[2,28],[3,14],[3,15],[3,28],[5,6],[5,20],[6,7],
                   [7,11],[7,21],[8,15],[9,30],[10,8],[10,28],[10,29],
-                  [11,22],[12,9],[12,17],[12,18],[12,29]] }
+                  [11,22],[12,9],[12,17],[12,18],[12,29]],
+	    1387:[[1,1],[1,2],[1,3],[1,4],[1,12],[1,13],[3,14],[3,15],[3,18],[4,26],[5,9],[5,27],
+                  [7,1],[7,10],[8,4],[9,19],[9,27],[10,17],[10,18],
+                  [11,22],[11,28],[12,6],[12,8],[12,25],[12,29]] }
